@@ -15,7 +15,7 @@ projNAD <- function() {
     .Call("PROJ4NADsInstalled", PACKAGE="rgdal")
 }
 
-"project" <- function(xy, proj, inv=FALSE) {
+"project" <- function(xy, proj, inv=FALSE, use_ob_tran=FALSE) {
 
     if (!is.numeric(xy)) stop("xy not numeric")
     if (is.matrix(xy)) nc <- dim(xy)[1]
@@ -24,6 +24,14 @@ projNAD <- function() {
 # 111216 RSB
     stopifnot(is.character(proj))
     stopifnot(length(proj) == 1)
+    stopifnot(is.logical(use_ob_tran))
+    if (use_ob_tran) {
+        gp <- grep("proj=ob_tran", proj)
+        if (length(gp) == 0) {
+            use_ob_tran <- FALSE
+            warning("project: use_ob_tran set FALSE")
+        }
+    }
     if(!inv) {
       res <- .C("project",
                 as.integer(nc),
@@ -42,6 +50,7 @@ projNAD <- function() {
                 x=double(nc),
                 y=double(nc),
                 proj,
+                as.integer(use_ob_tran),
                 NAOK=TRUE,
                 PACKAGE="rgdal")
     }
@@ -58,13 +67,24 @@ if (!isGeneric("spTransform"))
 		stop("No transformation possible from NA reference system")
 	if (is.na(CRSargs(CRSobj))) 
 		stop("No transformation possible to NA reference system")
+	dots = list(...)
+        if (!is.null(dots$use_ob_tran)) {
+          stopifnot(is.logical(dots$use_ob_tran))
+          if (dots$use_ob_tran) {
+            gp <- grep("proj=ob_tran", proj4string(x))
+            if (length(gp) == 0) {
+              use_ob_tran <- FALSE
+              warning("project: use_ob_tran set FALSE")
+            } else use_ob_tran <- TRUE
+          } else use_ob_tran <- FALSE
+        } else use_ob_tran <- FALSE
 	crds <- coordinates(x)
 	crds.names <- dimnames(crds)[[2]] # crds is matrix
 	if (ncol(crds) != 2) 	
 		warning("Only x- and y-coordinates are being transformed")
 	n <- nrow(crds)
 	res <- .Call("transform", proj4string(x), CRSargs(CRSobj), n,
-		as.double(crds[,1]), as.double(crds[,2]),
+		as.double(crds[,1]), as.double(crds[,2]), use_ob_tran,
 		PACKAGE="rgdal")
 	if (any(!is.finite(res[[1]])) || any(!is.finite(res[[2]]))) {
 		k <- which(!is.finite(res[[1]]) || !is.finite(res[[2]]))
@@ -84,7 +104,7 @@ setMethod("spTransform", signature("SpatialPoints", "CRS"), spTransform.SpatialP
 
 "spTransform.SpatialPointsDataFrame" <- function(x, CRSobj, ...) {
 	xSP <- as(x, "SpatialPoints")
-	resSP <- spTransform(xSP, CRSobj)
+	resSP <- spTransform(xSP, CRSobj, ...)
 	# xDF <- as(x, "data.frame")
 	xDF <- x@data # little need to add unique row.names here!
 	res <- SpatialPointsDataFrame(coords=coordinates(resSP), data=xDF,
@@ -108,11 +128,12 @@ setMethod("spTransform", signature("SpatialGridDataFrame", "CRS"),
 		spTransform(as(x, "SpatialPixelsDataFrame"), CRSobj, ...)})
 
 
-".spTransform_Line" <- function(x, to_args, from_args, ii, jj) {
+".spTransform_Line" <- function(x, to_args, from_args, ii, jj,
+                use_ob_tran=use_ob_tran) {
 	crds <- slot(x, "coords")
 	n <- nrow(crds)
 	res <- .Call("transform", from_args, to_args, n,
-		as.double(crds[,1]), as.double(crds[,2]),
+		as.double(crds[,1]), as.double(crds[,2]), use_ob_tran,
 		PACKAGE="rgdal")
 	if (any(!is.finite(res[[1]])) || any(!is.finite(res[[2]]))) {
 		k <- which(!is.finite(res[[1]]) || !is.finite(res[[2]]))
@@ -128,13 +149,15 @@ setMethod("spTransform", signature("SpatialGridDataFrame", "CRS"),
 
 #setMethod("spTransform", signature("Sline", "CRS"), spTransform.Sline)
 
-".spTransform_Lines" <- function(x, to_args, from_args, ii) {
+".spTransform_Lines" <- function(x, to_args, from_args, ii,
+                use_ob_tran=use_ob_tran) {
 	ID <- slot(x, "ID")
 	input <- slot(x, "Lines")
 	n <- length(input)
 	output <- vector(mode="list", length=n)
 	for (i in 1:n) output[[i]] <- .spTransform_Line(input[[i]], 
-		to_args=to_args, from_args=from_args, ii=ii, jj=i)
+		to_args=to_args, from_args=from_args, ii=ii, jj=i,
+                use_ob_tran=use_ob_tran)
 	x <- Lines(output, ID)
 	x
 }
@@ -148,18 +171,30 @@ setMethod("spTransform", signature("SpatialGridDataFrame", "CRS"),
 	to_args <- CRSargs(CRSobj)
 	if (is.na(to_args)) 
 		stop("No transformation possible to NA reference system")
+	dots = list(...)
+        if (!is.null(dots$use_ob_tran)) {
+          stopifnot(is.logical(dots$use_ob_tran))
+          if (dots$use_ob_tran) {
+            gp <- grep("proj=ob_tran", proj4string(x))
+            if (length(gp) == 0) {
+              use_ob_tran <- FALSE
+              warning("project: use_ob_tran set FALSE")
+            } else use_ob_tran <- TRUE
+          } else use_ob_tran <- FALSE
+        } else use_ob_tran <- FALSE
 	input <- slot(x, "lines")
 	n <- length(input)
 	output <- vector(mode="list", length=n)
 	for (i in 1:n) output[[i]] <- .spTransform_Lines(input[[i]], 
-		to_args=to_args, from_args=from_args, ii=i)
+		to_args=to_args, from_args=from_args, ii=i,
+                use_ob_tran=use_ob_tran)
 	res <- SpatialLines(output, proj4string=CRS(to_args))
 	res
 }
 setMethod("spTransform", signature("SpatialLines", "CRS"), spTransform.SpatialLines)
 "spTransform.SpatialLinesDataFrame" <- function(x, CRSobj, ...) {
 	xSP <- as(x, "SpatialLines")
-	resSP <- spTransform(xSP, CRSobj)
+	resSP <- spTransform(xSP, CRSobj, ...)
 	xDF <- as(x, "data.frame")
 	res <- SpatialLinesDataFrame(sl=resSP, data=xDF, match.ID = FALSE)
 	res
@@ -169,11 +204,12 @@ setMethod("spTransform", signature("SpatialLinesDataFrame", "CRS"), spTransform.
 
 
 
-".spTransform_Polygon" <- function(x, to_args, from_args, ii, jj) {
+".spTransform_Polygon" <- function(x, to_args, from_args, ii, jj,
+                use_ob_tran=use_ob_tran) {
 	crds <- slot(x, "coords")
 	n <- nrow(crds)
 	res <- .Call("transform", from_args, to_args, n,
-		as.double(crds[,1]), as.double(crds[,2]),
+		as.double(crds[,1]), as.double(crds[,2]), use_ob_tran,
 		PACKAGE="rgdal")
 	if (any(!is.finite(res[[1]])) || any(!is.finite(res[[2]]))) {
 		k <- which(!is.finite(res[[1]]) || !is.finite(res[[2]]))
@@ -188,13 +224,15 @@ setMethod("spTransform", signature("SpatialLinesDataFrame", "CRS"), spTransform.
 }
 
 
-".spTransform_Polygons" <- function(x, to_args, from_args, ii) {
+".spTransform_Polygons" <- function(x, to_args, from_args, ii,
+                use_ob_tran=use_ob_tran) {
 	ID <- slot(x, "ID")
 	input <- slot(x, "Polygons")
 	n <- length(input)
 	output <- vector(mode="list", length=n)
 	for (i in 1:n) output[[i]] <- .spTransform_Polygon(input[[i]], 
-		to_args=to_args, from_args=from_args, ii=ii, jj=i)
+		to_args=to_args, from_args=from_args, ii=ii, jj=i,
+                use_ob_tran=use_ob_tran)
 	res <- Polygons(output, ID)
         if (!is.null(comment(x))) comment(res) <- comment(x)
 	res
@@ -208,11 +246,23 @@ setMethod("spTransform", signature("SpatialLinesDataFrame", "CRS"), spTransform.
 	to_args <- CRSargs(CRSobj)
 	if (is.na(to_args)) 
 		stop("No transformation possible to NA reference system")
+	dots = list(...)
+        if (!is.null(dots$use_ob_tran)) {
+          stopifnot(is.logical(dots$use_ob_tran))
+          if (dots$use_ob_tran) {
+            gp <- grep("proj=ob_tran", proj4string(x))
+            if (length(gp) == 0) {
+              use_ob_tran <- FALSE
+              warning("project: use_ob_tran set FALSE")
+            } else use_ob_tran <- TRUE
+          } else use_ob_tran <- FALSE
+        } else use_ob_tran <- FALSE
 	input <- slot(x, "polygons")
 	n <- length(input)
 	output <- vector(mode="list", length=n)
 	for (i in 1:n) output[[i]] <- .spTransform_Polygons(input[[i]], 
-		to_args=to_args, from_args=from_args, ii=i)
+		to_args=to_args, from_args=from_args, ii=i,
+                use_ob_tran=use_ob_tran)
 	res <- SpatialPolygons(output, pO=slot(x, "plotOrder"), 
 		proj4string=CRSobj)
 	res
@@ -221,7 +271,7 @@ setMethod("spTransform", signature("SpatialPolygons", "CRS"), spTransform.Spatia
 
 "spTransform.SpatialPolygonsDataFrame" <- function(x, CRSobj, ...) {
 	xSP <- as(x, "SpatialPolygons")
-	resSP <- spTransform(xSP, CRSobj)
+	resSP <- spTransform(xSP, CRSobj, ...)
 	xDF <- as(x, "data.frame")
 	res <- SpatialPolygonsDataFrame(Sr=resSP, data=xDF, match.ID = FALSE)
 	res
