@@ -101,8 +101,8 @@ print.GDALobj <- function(x, ...) {
 	cat("rows       ", x[1], "\n")
 	cat("columns    ", x[2], "\n")
 	cat("bands      ", x[3], "\n")
-	cat("origin.x       ", x[4], "\n")
-	cat("origin.y       ", x[5], "\n")
+	cat("lower left origin.x       ", x[4], "\n")
+	cat("lower left origin.y       ", x[5], "\n")
 	cat("res.x      ", x[6], "\n")
 	cat("res.y      ", x[7], "\n")
         cat("ysign      ", attr(x, "ysign"), "\n")
